/* These styles are generated from project.scss. */

.alert-debug {
  color: black;
  background-color: white;
  border-color: #d6e9c6;
}

.alert-error {
  color: #b94a48;
  background-color: #f2dede;
  border-color: #eed3d7;
}

/* This is a fix for the bootstrap4 alpha release */
@media (max-width: 47.9em) {
  .navbar-nav .nav-item {
    float: none;
    width: 100%;
    display: inline-block;
  }

  .navbar-nav .nav-item + .nav-item {
    margin-left: 0;
  }

  .nav.navbar-nav.pull-xs-right {
    float: none !important;
  }
}

/* Display django-debug-toolbar.
   See https://github.com/django-debug-toolbar/django-debug-toolbar/issues/742
   and https://github.com/pydanny/cookiecutter-django/issues/317
*/
[hidden][style="display: block;"] {
  display: block !important;
}
