# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-06-30 21:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='GiroTemplate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('subject', models.CharField(max_length=100)),
                ('text_template', models.TextField()),
                ('html_template', models.TextField()),
                ('trigger', models.CharField(max_length=100, unique=True)),
            ],
        ),
    ]
