{% extends "base.html" %}

{% block content %}
<h1>Lokallag i NMU</h1>

<table>
 <thead>
   <tr>
     <th>Lokallag
     <th title="Interessante medlemar er dei som har betalt i fjor eller i år">«Interessante»
     <th title="Betalande medlemar">Betalande
     <th title="Teljande medlemar er under 26 og har betalt">Teljande
     <th title="Medlemar, utmelde, innmelde, folk som ikkje har betalt o.l. Alle saman, historisk sett.">Alle
   </tr>
 </thead>

 <tbody>
  {% for l in lokallag %}
  <tr> <td><a href={{ l.slug }}>{{ l }}</a>
       <td>{{ l.medlem_set.interessante|length }}
       <td>{{ l.medlem_set.betalande|length }}
       <td>{{ l.medlem_set.teljande|length }}
       <td>{{ l.num_medlemar }}
  </tr>
  {% endfor %}
 </tbody>

</table>

{% endblock content %}
